@@ -6,7 +6,7 @@ use strict;
 use warnings;
 
 package Raisin::Entity;
-$Raisin::Entity::VERSION = '0.91';
+$Raisin::Entity::VERSION = '0.92';
 use parent 'Exporter';
 
 use Carp;
@@ -145,7 +145,9 @@ sub _make_exposition {
     my @columns = do {
         if (blessed($data)) {
             if ($data->isa('DBIx::Class::ResultSet')) {
-                keys %{ $data->first->columns_info };
+                my %columns = keys %{ $data->first->columns_info };
+                $data->reset;
+                %columns;
             }
             elsif ($data->isa('DBIx::Class::Core')) {
                 keys %{ $data->columns_info };
@@ -188,7 +190,7 @@ Raisin::Entity - A simple facade to use with your API
 
 =head1 VERSION
 
-version 0.91
+version 0.92
 
 =head1 SYNOPSIS
 
